#!/bin/bash
set -euo pipefail

echo -e '1\t2\t3' > test.bed
bgzip test.bed
tabix test.bed.gz
htsfile test.bed.gz > /dev/null


set -ex



bgzip --version
htsfile --version
tabix --version
conda inspect linkages -p $PREFIX $PKG_NAME
exit 0
